@@ -3,7 +3,7 @@ package Test::SharedFork;
 use strict;
 use warnings;
 use base 'Test::Builder::Module';
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 use Test::Builder 0.32; # 0.32 or later is needed
 use Test::SharedFork::Scalar;
 use Test::SharedFork::Array;
@@ -16,9 +16,10 @@ BEGIN {
     $STORE = Test::SharedFork::Store->new(
         cb => sub {
             my $store = shift;
-            tie __PACKAGE__->builder->{Curr_Test}, 'Test::SharedFork::Scalar', 0, $store;
+            tie __PACKAGE__->builder->{Curr_Test}, 'Test::SharedFork::Scalar', $store;
             tie @{ __PACKAGE__->builder->{Test_Results} }, 'Test::SharedFork::Array', $store;
-        }
+        },
+        builder => __PACKAGE__->builder,
     );
 
     no strict 'refs';
@@ -45,4 +46,4 @@ BEGIN {
 1;
 __END__
 
-#line 96
+#line 97
